@@ -1,17 +1,18 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "kele" "0.7.0"
+(define-package "kele" "20251111.416"
   "Spritzy Kubernetes cluster management."
   '((emacs   "29.1")
     (async   "1.9.7")
     (dash    "2.19.1")
     (f       "0.20.0")
+    (ht      "2.3")
     (memoize "0")
     (plz     "0.8.0")
     (s       "1.13.0")
     (yaml    "0.5.1"))
   :url "https://github.com/jinnovation/kele.el"
-  :commit "ddaae424cf142e1cb6c46824aede3cd0479f2669"
-  :revdesc "ddaae424cf14"
+  :commit "047ae15e8c9e50d70dd009e1354beb9363c58243"
+  :revdesc "047ae15e8c9e"
   :keywords '("kubernetes" "tools")
   :authors '(("Jonathan Jin" . "me@jonathanj.in"))
   :maintainers '(("Jonathan Jin" . "me@jonathanj.in")))
